*! version 1.0.0 December 8, 2017 @ 04:26:51
*! Creates an example docx document 
version 15.0
set more off 

** some useful definitions
local h2 font("",15)
local code font("Courier New",,"0000aa")

capture putpdf clear

putpdf begin

putpdf paragraph, `h2'
putpdf text ("A simple putpdf document")

putpdf paragraph
putpdf text ("For ")
putpdf text ("putpdf"), `code'
putpdf text (", the body of the document is in a series of ")
putpdf text ("putpdf paragraph"), `code'
putpdf text (" and ")
putpdf text ("putpdf text"), `code'
putpdf text (" commands.")

putpdf paragraph
putpdf text ("This is a typical paragraph. Any change to font type requires a new ")
putpdf text ("putpdf text"), `code'
putpdf text (" command to set the font. Thus, if you want ")
putpdf text ("emphasis"), italic
putpdf text (", then you need a separate command using the ")
putpdf text ("italic"), `code'
putpdf text (" option. Similarly, ")
putpdf text ("bold"), bold
putpdf text (" requires the ")
putpdf text ("bold"), `code'
putpdf text (" option. Including ")
putpdf text ("code"), `code'
putpdf text (" can be made easier by having a local macro to define the way that you'd like code to look.")

putpdf paragraph
putpdf text ("putpdf"), `code'
putpdf text (" is meant for writing papers. It is good for including results and tables, but is not made for including Stata code and literal Stata output. Because the document itself is contained in ")
putpdf text ("putpdf"), `code'
putpdf text (" commands, Stata commands need nothing special to be used.")

putpdf paragraph
putpdf text ("What will now happen (behind the scenes) is that the ")
putpdf text ("auto"), `code'
putpdf text (" dataset will be opened, some summary statistics will get computed using ")
putpdf text ("tabstat"), `code'
putpdf text (" and then a graph will be created and included.")

clear
sysuse auto

tabstat price mpg weight displacement, ///
   statistics( count mean sd min p25 p50 p75 max ) ///
   save

** needed because putpdf has trouble with the transpose and names
matrix Stats = r(StatTotal)'

putpdf paragraph
putpdf text ("Here is some interesting information about 1978 automobiles:")

putpdf table tabstat1 = matrix(Stats), rownames colnames nformat(%9.0g)

** this could be done with matrices, but it's conceptually easier to use -summarize-
summarize price
local meanPrice : display %5.0fc r(mean)

putpdf paragraph
putpdf text ("Note that the mean price was $`meanPrice' (rounded to the nearest dollar).")

graph matrix mpg weight length gear_ratio
graph export gpmatrix_pdf.png, replace

putpdf paragraph
putpdf text ("Finally, here is the graph. For ")
putpdf text ("putpdf"), `code'
putpdf text (", both the height and width must be specified with the correct aspect ratio, otherwise the graph will be distorted:")

putpdf paragraph, halign(center)
putpdf image gpmatrix_pdf.png, height(8cm) width(`=8/4 * 5.5'cm)

putpdf paragraph
putpdf text ("Take a look at ")
putpdf text ("help putpdf"), `code'
putpdf text (" for the full story.")

putpdf save "putpdf_ex", replace
