*! version 1.0.0 December 8, 2017 @ 03:17:54
*! Creates an example docx document 
version 15.0
set more off 

** some useful definitions
local code font("Courier New",,"0000aa")

capture putdocx clear

putdocx begin

putdocx paragraph, style(Heading2)
A simple putwrap document

If you just have narrative, as would be typical for a document, you can just type the narrative.
In this way, using putwrap makes life a bit simpler.

Paragraphs are in the default style for the document, and get separated by a blank line.
There is no need to put default text or default paragraphs into commands.
This should make narrative easier to read and easier to edit.

As soon as you want special fonts, such as code, you still have to use
putdocx text ("putdocx"), `code'
 syntax, and to pay close attention to whitespace.

When using this wrapper you do need to offset Stata code, because it cannot be simply interpreted.
You do this by beginning a Stata code block with
putdocx text ("putdocx pause"), `code'
, and ending the block with
putdocx text ("putdocx resume"), `code'
.

putdocx text ("putdocx"), `code'
 is meant for writing papers.
It is good for including results and tables, but is not made for including Stata code and literal Stata output.
The source file shows that special fonts are still a bit ugly, even when using a wrapper.

Even so, including results with the body of the text is not hard.
Embedding Stata inline results is no different than in standard
putdocx text ("putdocx"), `code'
.

What will now happen (behind the scenes) is that the auto dataset will be opened, some summary statistics will get computed using the tabstat command.
The results will then be put in the document.
This document will then create a graph and include it.
** Here is Stata code
putdocx pause
  clear
  sysuse auto

  tabstat price mpg weight displacement, ///
     statistics( count mean sd min p25 p50 p75 max ) ///
     save

** needed because returnd matrices are not readily maniuplated
  matrix Stats = r(StatTotal)'

** this could be done with matrices, but it's conceptually easier to use -summarize-
  summarize price
  local meanPrice : display %5.0fc r(mean)
putdocx resume
** Here is the end of the Stata code

Here is some interesting summary information about 1978 automobiles:

  putdocx table tabstat1 = matrix(Stats), rownames colnames nformat(%9.0g)

Note that the mean price was $`meanPrice' (rounded to the nearest dollar).

** More Stata code
putdocx pause
  graph matrix mpg weight length gear_ratio
  graph export gpmatrix_putwrap_docx.png, replace
putdocx resume

Finally, here is the graph, but now the size can be specified in a typical unit:

  putdocx paragraph, halign(center)
  putdocx image gpmatrix_putwrap_docx.png, height(8cm)

Take a look at
putdocx text ("help putwrap"), `code'
 for the full story.

putdocx save "putwrap_docx_ex", replace
